==> vtigercrm-5.3.0p0.tgz: modules/MailManager/language/es_es.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.1
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$mod_strings = Array (
	'MailManager' => 'Administrador Correo',
	
	// Translations for JS (please use the prefix JSLBL in key)
	'JSLBL_Loading_Please_Wait'  => 'Cargando, por favor espera',
	'JSLBL_Loading'              => 'Cargando',
	'JSLBL_Settings'             => 'Configuración',
	'JSLBL_Opening'              => 'Abriendo',
	'JSLBL_Deleting'              => 'Eliminando',  
	'JSLBL_Updating'             => 'Actualizando',
	'JSLBL_Associating'          => 'Asociando',
	'JSLBL_Saving_And_Verifying' => 'Guardando & Verificando',
	'JSLBL_Failed_To_Open_Mail'  => 'No se ha podido abrir el correo',
	'JSLBL_Finding_Relation'     => 'Buscando relación',
	'JSLBL_Find_Relation_Now'    => 'Buscar relación ahora',
	'JSLBL_Searching'            => 'Buscando',
	'JSLBL_Searching_Please_Wait'=> 'Buscando, por favor espera',
	'JSLBL_Sending'              => 'Enviando',
	'JSLBL_Replied'              => 'Respondido',
	'JSLBL_Failed_To_Send_Mail'  => 'No se ha podido enviar el correo',
	'JSLBL_Recepient_Cannot_Be_Empty' => 'Destinatario no puede quedar vacío',
	'JSLBL_SendWith_EmptySubject'     => '¿Enviar sin asunto?',
	'JSLBL_Removing'                  => 'Eliminando',
	'JSLBL_Choose_Server_Type'        => 'Elige tipo servidor',
	'JSLBL_Other'                     => 'Otro',
	'JSLBL_Gmail'                     => 'Gmail',
	'JSLBL_Fastmail'                  => 'Fastmail',
	'JSLBL_Search_For_Email'          => 'Buscar correos',
	'JSLBL_Nothing_Found'             => 'No se ha encontrado nada',
	'JSLBL_Delete_Confirm'            =>'¿Quieres eliminar los correos permanentemente?',
	'JSLBL_Delete_Mails_Confirm'      =>'¿Quieres eliminar los correos?',
	'JSLBL_Receipents_Warning_Message'=>'Por favor, selecciona destinatarios',
	'JSLBL_NO_MATCH'				  => 'No se ha encontrado coincidencia',
	'JSLBL_Saving'					=> 'Guardando',
	'JSLBL_Failed_To_Save_Mail'		=>	'No se ha podido guardar el correo',
	'JSLBL_ATTACHMENT_NOT_DELETED'	=>	'No se ha podido eliminar el adjunto',
	'JSLBL_UPLOAD_CANCEL'	=> 'Cancelar',
	'JSLBL_UPLOAD_DROPFILES'=>'Arrastra los ficheros aqui para cargarlos',
	'JSLBL_UPLOAD_FILE'=>'Cargar',
	'JSLBL_UPLOAD_DELETE'=>'[x]',
	'JSLBL_UPLOAD_FAILED'=>'Fallido',
	'JSLBL_FILEUPLOAD_LIMIT_EXCEEDED'=>'Límite de carga excedida!!',
	'JSLBL_MAIL_SENT'=>'Correo Enviado',
	'JSLBL_EMAIL_FORMAT_INCORRECT'=>'Por favor, introduce dirección de email correcta',
	'JSLBL_Saving'=>'Guardando',
	'JSLBL_SaveWith_EmptySubject'=>'¿Guardar sin asunto?',
	'JSLBL_Delete'            =>  'Eliminar',
	'JSLBL_Drafts'=>'Borradores',
	'JSLBL_PASSWORD_CANNOT_BE_EMPTY'=>'La contraseña no puede quedar vacía',
	'JSLBL_SERVERNAME_CANNOT_BE_EMPTY'=>'El nombre del servidor no puede quedar vacío',
	'JSLBL_USERNAME_CANNOT_BE_EMPTY'=>'El nombre del usuario no puede quedar vacío',
	'JSLBL_ACCOUNTNAME_CANNOT_EMPTY'=>'El nombre de la cuenta no puede quedar vacío',
	'JSLBL_FROM'=>'De:',
	'JSLBL_DATE'=>'Fecha: ',
	'JSLBL_SUBJECT'=>'Asunto: ',
	'JSLBL_TO'=>'A: ',
	'JSLBL_CC'=>'Cc: ',
	'JSLBL_FORWARD_MESSAGE_TEXT'=>'---------- Mensaje Reenviado ----------',
	'JSLBL_PLEASE_SELECT_ATLEAST_ONE_MAIL'=>'Por favor selecciona al menos un email',
	'JSLBL_PLEASE_SELECT_ATLEAST_ONE_RECORD'=>'Por favor selecciona al menos un registro',
	'JSLBL_MAIL_MOVED'=>'Correo(s) movido',
	'JSLBL_MOVING'=>'Moviendo Correo(s)',
	'JSLBL_LOADING_FOLDERS' => 'Cargando Carpetas..',
	'JSLBL_ADD_COMMENT'=>'Añadir Comentario',
    'JSLBL_Yahoo'=>'Yahoo',
    'JSLBL_CANNOT_ADD_EMPTY_COMMENT' => 'Comentario no puede quedar vacío',
    'JSLBL_NO_EMAILS_SELECTED' => 'No se han seleccionado correos.',
    'JSLBL_ENTER_SOME_VALUE' => 'Introduce una cadena para buscar',
    'JSLBL_DRAFT_MAIL_SAVED'=>'Se ha guardado el correo en Borradores',
    
	// General translations
	'LBL_Folders'         => 'Carpetas',
	'LBL_Newer'           => 'Más nuevos',
	'LBL_Older'           => 'Más viejos',
	'LBL_No_Mails_Found'  => 'No se han encontrado correos.',
	'LBL_Go_Back'         => 'Atrás',
	'LBL_Reply_All'       => 'Responder a todos',
	'LBL_Reply'           => 'Responder',
	'LBL_Mark_As_Unread'  => 'Marcar como leído',
	'LBL_Previous'        => 'anterior',
	'LBL_Next'            => 'siguiente',
	'LBL_RELATED_RECORDS' => 'Registros Relacionados',
	'LBL_Mailbox'         => 'Buzón',
	'LBL_Outbox'          => 'Salida CRM',
	'LBL_Like'            => 'como',
	'LBL_Mail_Server'     => 'Nombre/IP Servidor de Correo',
	'LBL_Refresh'         => 'Actualizar',
	'LBL_Cancel'          => 'Cancelar',
	'LBL_Send'            => 'Enviar',
	'LBL_Compose'         => 'Redactar',
	'LBL_Forward'         => 'Reenviar',
	'LBL_Remove'          => 'Eliminar',
	'LBL_Associate'       => 'Asociar',
	'LBL_Create_Contact'  => 'Crear contacto',
	'LBL_No_Matching_Record_Found' => 'No se han encontrado registros.',
	'LBL_ACTIONS'         => 'Acciones',
	'LBL_Search'          => 'Buscar',
	'LBL_Delete'            =>  'Eliminar',
	
	'LBL_Username'             => 'Nombre Usuario',
	'LBL_Your_Mailbox_Account' => 'tu cuenta de correo',
	'LBL_Password'             => 'Contraseña',
	'LBL_Account_Password'     => 'contraseña cuenta',
	'LBL_Protocol'    => 'Protocolo',
	'LBL_Imap2'       => 'IMAP2',
	'LBL_Imap4'       => 'IMAP4',
	'LBL_SSL_Options' => 'Opciones SSL',
	'LBL_No_TLS'      => 'Sin TLS',
	'LBL_TLS'         => 'TLS',
	'LBL_SSL'         => 'SSL',
	'LBL_Certificate_Validations' => 'Validaciones de Certificado',
	'LBL_Validate_Cert'           => 'Validar Certificado',
	'LBL_Do_Not_Validate_Cert'    => 'No validar Certificado',
	'LBL_SELECT_ACCOUNT_TYPE'     => 'Selecciona Tipo Cuenta',
	
	'LBL_FROM'        => 'De',
	'LBL_TO'          => 'A',
	'LBL_CC'          => 'CC',
	'LBL_BCC'         => 'BCC',
	'LBL_Date'        => 'Fecha',
	'LBL_Attachments' => 'Adjuntos',
	'LBL_EMAIL_TEMPLATES_LIST'=>'Plantillas de Correo',
	'LBL_SELECT_EMAIL_TEMPLATE'=>'Selecciona Plantilla de Correo',
	'LBL_ATTACHMENTS'  =>'Adjunto:',
	'LBL_SELECT_DOCUMENTS'=>'Selecciona Documentos',
	'LBL_IN' =>'en',
	'LBL_FIND'=>'Buscar',
	'LBL_SAVE_NOW'=>'Guardar Ahora',
	'LBL_Drafts'=>'Borradores',
 	'LBL_NO_EMAILS_SELECTED' => 'No se ha seleccionado correos.',
	'LBL_SUBJECT'	=>	'Asunto',
	'LBL_WRITE_ACCESS_FOR'	=>'Permiso escritura para',
	'LBL_READ_ACCESS_FOR'	=>'Permiso lectura para',
	'LBL_MODULE_DENIED' => 'módulo denegado!',
	'LBL_REFRESH_TIME'=>'Frecuencia actualización',
	'LBL_NONE' => 'Ninguno',
	'LBL_5_MIN' => '5 Minutos',
	'LBL_10_MIN' => '10 Minutos',
	'LBL_MOVE_TO'=>'Mover a...',
    'LBL_MAILMANAGER_ADD_Contacts' => 'Añadir Contacto',
    'LBL_MAILMANAGER_ADD_Accounts' => 'Añadir Cuenta',
    'LBL_MAILMANAGER_ADD_Leads' => 'Añadir PreContacto',
    'LBL_MAILMANAGER_ADD_Calendar' => 'Añadir Tarea',
    'LBL_MAILMANAGER_ADD_HelpDesk' => 'Añadir Incidencia',
    'LBL_MAILMANAGER_ADD_Emails' => 'Adjuntar Correo',
    'LBL_MAILMANAGER_ADD_ModComments' => 'Añadir Comentario',
    'LBL_ADD' => 'Añadir'
);

?>

==> vtigercrm-5.4.0.tgz: modules/MailManager/language/es_es.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.1
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$mod_strings = Array (
	'MailManager' => 'Administrador Correo',
	
	// Translations for JS (please use the prefix JSLBL in key)
	'JSLBL_Loading_Please_Wait'  => 'Cargando, por favor espera',
	'JSLBL_Loading'              => 'Cargando',
	'JSLBL_Settings'             => 'Configuración',
	'JSLBL_Opening'              => 'Abriendo',
	'JSLBL_Deleting'              => 'Eliminando',  
	'JSLBL_Updating'             => 'Actualizando',
	'JSLBL_Associating'          => 'Asociando',
	'JSLBL_Saving_And_Verifying' => 'Guardando & Verificando',
	'JSLBL_Failed_To_Open_Mail'  => 'No se ha podido abrir el correo',
	'JSLBL_Finding_Relation'     => 'Buscando relación',
	'JSLBL_Find_Relation_Now'    => 'Buscar relación ahora',
	'JSLBL_Searching'            => 'Buscando',
	'JSLBL_Searching_Please_Wait'=> 'Buscando, por favor espera',
	'JSLBL_Sending'              => 'Enviando',
	'JSLBL_Replied'              => 'Respondido',
	'JSLBL_Failed_To_Send_Mail'  => 'No se ha podido enviar el correo',
	'JSLBL_Recepient_Cannot_Be_Empty' => 'Destinatario no puede quedar vacío',
	'JSLBL_SendWith_EmptySubject'     => '¿Enviar sin asunto?',
	'JSLBL_Removing'                  => 'Eliminando',
	'JSLBL_Choose_Server_Type'        => 'Elige tipo servidor',
	'JSLBL_Other'                     => 'Otro',
	'JSLBL_Gmail'                     => 'Gmail',
	'JSLBL_Fastmail'                  => 'Fastmail',
	'JSLBL_Search_For_Email'          => 'Buscar correos',
	'JSLBL_Nothing_Found'             => 'No se ha encontrado nada',
	'JSLBL_Delete_Confirm'            =>'¿Quieres eliminar los correos permanentemente?',
	'JSLBL_Delete_Mails_Confirm'      =>'¿Quieres eliminar los correos?',
	'JSLBL_Receipents_Warning_Message'=>'Por favor, selecciona destinatarios',
	'JSLBL_NO_MATCH'				  => 'No se ha encontrado coincidencia',
	'JSLBL_Saving'					=> 'Guardando',
	'JSLBL_Failed_To_Save_Mail'		=>	'No se ha podido guardar el correo',
	'JSLBL_ATTACHMENT_NOT_DELETED'	=>	'No se ha podido eliminar el adjunto',
	'JSLBL_UPLOAD_CANCEL'	=> 'Cancelar',
	'JSLBL_UPLOAD_DROPFILES'=>'Arrastra los ficheros aqui para cargarlos',
	'JSLBL_UPLOAD_FILE'=>'Cargar',
	'JSLBL_UPLOAD_DELETE'=>'[x]',
	'JSLBL_UPLOAD_FAILED'=>'Fallido',
	'JSLBL_FILEUPLOAD_LIMIT_EXCEEDED'=>'Límite de carga excedida!!',
	'JSLBL_MAIL_SENT'=>'Correo Enviado',
	'JSLBL_EMAIL_FORMAT_INCORRECT'=>'Por favor, introduce dirección de email correcta',
	'JSLBL_Saving'=>'Guardando',
	'JSLBL_SaveWith_EmptySubject'=>'¿Guardar sin asunto?',
	'JSLBL_Delete'            =>  'Eliminar',
	'JSLBL_Drafts'=>'Borradores',
	'JSLBL_PASSWORD_CANNOT_BE_EMPTY'=>'La contraseña no puede quedar vacía',
	'JSLBL_SERVERNAME_CANNOT_BE_EMPTY'=>'El nombre del servidor no puede quedar vacío',
	'JSLBL_USERNAME_CANNOT_BE_EMPTY'=>'El nombre del usuario no puede quedar vacío',
	'JSLBL_ACCOUNTNAME_CANNOT_EMPTY'=>'El nombre de la cuenta no puede quedar vacío',
	'JSLBL_FROM'=>'De:',
	'JSLBL_DATE'=>'Fecha: ',
	'JSLBL_SUBJECT'=>'Asunto: ',
	'JSLBL_TO'=>'A: ',
	'JSLBL_CC'=>'Cc: ',
	'JSLBL_FORWARD_MESSAGE_TEXT'=>'---------- Mensaje Reenviado ----------',
	'JSLBL_PLEASE_SELECT_ATLEAST_ONE_MAIL'=>'Por favor selecciona al menos un email',
	'JSLBL_PLEASE_SELECT_ATLEAST_ONE_RECORD'=>'Por favor selecciona al menos un registro',
	'JSLBL_MAIL_MOVED'=>'Correo(s) movido',
	'JSLBL_MOVING'=>'Moviendo Correo(s)',
	'JSLBL_LOADING_FOLDERS' => 'Cargando Carpetas..',
	'JSLBL_ADD_COMMENT'=>'Añadir Comentario',
    'JSLBL_Yahoo'=>'Yahoo',
    'JSLBL_CANNOT_ADD_EMPTY_COMMENT' => 'Comentario no puede quedar vacío',
    'JSLBL_NO_EMAILS_SELECTED' => 'No se han seleccionado correos.',
    'JSLBL_ENTER_SOME_VALUE' => 'Introduce una cadena para buscar',
    'JSLBL_DRAFT_MAIL_SAVED'=>'Se ha guardado el correo en Borradores',
    
	// General translations
	'LBL_Folders'         => 'Carpetas',
	'LBL_Newer'           => 'Más nuevos',
	'LBL_Older'           => 'Más viejos',
	'LBL_No_Mails_Found'  => 'No se han encontrado correos.',
	'LBL_Go_Back'         => 'Atrás',
	'LBL_Reply_All'       => 'Responder a todos',
	'LBL_Reply'           => 'Responder',
	'LBL_Mark_As_Unread'  => 'Marcar como leído',
	'LBL_Previous'        => 'anterior',
	'LBL_Next'            => 'siguiente',
	'LBL_RELATED_RECORDS' => 'Registros Relacionados',
	'LBL_Mailbox'         => 'Buzón',
	'LBL_Outbox'          => 'Salida CRM',
	'LBL_Like'            => 'como',
	'LBL_Mail_Server'     => 'Nombre/IP Servidor de Correo',
	'LBL_Refresh'         => 'Actualizar',
	'LBL_Cancel'          => 'Cancelar',
	'LBL_Send'            => 'Enviar',
	'LBL_Compose'         => 'Redactar',
	'LBL_Forward'         => 'Reenviar',
	'LBL_Remove'          => 'Eliminar',
	'LBL_Associate'       => 'Asociar',
	'LBL_Create_Contact'  => 'Crear contacto',
	'LBL_No_Matching_Record_Found' => 'No se han encontrado registros.',
	'LBL_ACTIONS'         => 'Acciones',
	'LBL_Search'          => 'Buscar',
	'LBL_Delete'            =>  'Eliminar',
	
	'LBL_Username'             => 'Nombre Usuario',
	'LBL_Your_Mailbox_Account' => 'tu cuenta de correo',
	'LBL_Password'             => 'Contraseña',
	'LBL_Account_Password'     => 'contraseña cuenta',
	'LBL_Protocol'    => 'Protocolo',
	'LBL_Imap2'       => 'IMAP2',
	'LBL_Imap4'       => 'IMAP4',
	'LBL_SSL_Options' => 'Opciones SSL',
	'LBL_No_TLS'      => 'Sin TLS',
	'LBL_TLS'         => 'TLS',
	'LBL_SSL'         => 'SSL',
	'LBL_Certificate_Validations' => 'Validaciones de Certificado',
	'LBL_Validate_Cert'           => 'Validar Certificado',
	'LBL_Do_Not_Validate_Cert'    => 'No validar Certificado',
	'LBL_SELECT_ACCOUNT_TYPE'     => 'Selecciona Tipo Cuenta',
	
	'LBL_FROM'        => 'De',
	'LBL_TO'          => 'A',
	'LBL_CC'          => 'CC',
	'LBL_BCC'         => 'BCC',
	'LBL_Date'        => 'Fecha',
	'LBL_Attachments' => 'Adjuntos',
	'LBL_EMAIL_TEMPLATES_LIST'=>'Plantillas de Correo',
	'LBL_SELECT_EMAIL_TEMPLATE'=>'Selecciona Plantilla de Correo',
	'LBL_ATTACHMENTS'  =>'Adjunto:',
	'LBL_SELECT_DOCUMENTS'=>'Selecciona Documentos',
	'LBL_IN' =>'en',
	'LBL_FIND'=>'Buscar',
	'LBL_SAVE_NOW'=>'Guardar Ahora',
	'LBL_Drafts'=>'Borradores',
 	'LBL_NO_EMAILS_SELECTED' => 'No se ha seleccionado correos.',
	'LBL_SUBJECT'	=>	'Asunto',
	'LBL_WRITE_ACCESS_FOR'	=>'Permiso escritura para',
	'LBL_READ_ACCESS_FOR'	=>'Permiso lectura para',
	'LBL_MODULE_DENIED' => 'módulo denegado!',
	'LBL_REFRESH_TIME'=>'Frecuencia actualización',
	'LBL_NONE' => 'Ninguno',
	'LBL_5_MIN' => '5 Minutos',
	'LBL_10_MIN' => '10 Minutos',
	'LBL_MOVE_TO'=>'Mover a...',
    'LBL_MAILMANAGER_ADD_Contacts' => 'Añadir Contacto',
    'LBL_MAILMANAGER_ADD_Accounts' => 'Añadir Cuenta',
    'LBL_MAILMANAGER_ADD_Leads' => 'Añadir PreContacto',
    'LBL_MAILMANAGER_ADD_Calendar' => 'Añadir Tarea',
    'LBL_MAILMANAGER_ADD_HelpDesk' => 'Añadir Incidencia',
    'LBL_MAILMANAGER_ADD_Emails' => 'Adjuntar Correo',
    'LBL_MAILMANAGER_ADD_ModComments' => 'Añadir Comentario',
    'LBL_ADD' => 'Añadir',
	'JSLBL_SendWith_EmptyText' => '¿Enviar sin texto en el cuerpo?',
	'LBL_ALLMAILS' => 'Todos los Correos',
	'LBL_TO_CONTACTS' => 'A Contactos',
	'LBL_TO_ACCOUNTS' => 'A Cuentas',
	'LBL_TO_LEADS' => 'A PreContactos',
	'LBL_TO_USERS' => 'A Usuarios',
	'LBL_SENT_MAILS' => 'Correos Enviados'
);

?>
